@@ -12,7 +12,7 @@
 #' @return If the argument \code{bothVals} is \code{FALSE}, the robust final prediction error (numeric). Otherwise,
 #' the two terms of the RFPE expression in equation (5.39), Section 5.6.2 of Maronna
 #' et al. (2019), \url{http://www.wiley.com/go/maronna/robust}, are returned separately 
-#' in a list with components named \code{minRhoMM} and \code{penaltyRFPE}
+#' in a list with components named \code{minRhoMM.C} and \code{penaltyRFPE}
 #' 
 #' @rdname lmrobdetMM.RFPE
 #' @author Victor Yohai, \email{victoryohai@gmail.com}, Matias Salibian-Barrera, \email{matias@stat.ubc.ca}
@@ -46,7 +46,7 @@ lmrobdetMM.RFPE <- function(object, scale = NULL, bothVals = FALSE)
   if(!bothVals) {
     return( (a2 + b2/d2/length(res)) ) # (a + b/d)*6 / tun^2 )
   } else {
-    return( list(minRhoMM=a2, penaltyRFPE=b2/d2/length(res)) )
+    return( list(minRhoMM.C=a2, penaltyRFPE=b2/d2/length(res)) )
   }
 }
 
